@@ -65,12 +65,7 @@ class MySQLConnection:
 		self._dbPW = dbPW
 		self._dbUsername = dbUsername
 
-		try:
-			self._db_connect()
-		except Exception:
-			sys.stderr.write("Error connecting to database: " + dbName + "for user: " + dbUsername)
-			raise
-			
+		self._db_connect()
 
 	def __del__(self):
 		""" Destructor """
@@ -91,11 +86,7 @@ class MySQLConnection:
 		"""
 		we do this in multiple places and it's nice to be consistent with handling errors
 		"""
-		try:
-			return cursor.execute(sql, parms)
-		except Exception:
-			sys.stderr.write("Error executing cursor on database: " + self._dbName + "for user: " + self._dbUsername)
-			raise
+		return cursor.execute(sql, parms)
 
 
 	@contextmanager
